@@ -13,13 +13,16 @@
 """Runtime REST adapter."""
 
 import logging
+from datetime import datetime
 from typing import Dict, Any, List, Union, Optional
 import json
 
 from .base import RestAdapterBase
 from .program import Program
 from .program_job import ProgramJob
+from .runtime_session import RuntimeSession
 from ...utils import RuntimeEncoder
+from ...utils.converters import local_to_utc
 from .cloud_backend import CloudBackend
 
 logger = logging.getLogger(__name__)
@@ -31,7 +34,7 @@ class Runtime(RestAdapterBase):
     URL_MAP = {
         "programs": "/programs",
         "jobs": "/jobs",
-        "backends": "/devices",
+        "backends": "/backends",
     }
 
     def program(self, program_id: str) -> "Program":
@@ -56,6 +59,17 @@ class Runtime(RestAdapterBase):
         """
         return ProgramJob(self.session, job_id)
 
+    def runtime_session(self, session_id: str) -> "RuntimeSession":
+        """Return an adapter for the session.
+
+        Args:
+            session_id: Job ID of the first job in a session.
+
+        Returns:
+            The session adapter.
+        """
+        return RuntimeSession(self.session, session_id)
+
     def list_programs(self, limit: int = None, skip: int = None) -> Dict[str, Any]:
         """Return a list of runtime programs.
 
@@ -120,6 +134,9 @@ class Runtime(RestAdapterBase):
         project: Optional[str] = None,
         log_level: Optional[str] = None,
         session_id: Optional[str] = None,
+        job_tags: Optional[List[str]] = None,
+        max_execution_time: Optional[int] = None,
+        start_session: Optional[bool] = False,
     ) -> Dict:
         """Execute the program.
 
@@ -133,12 +150,15 @@ class Runtime(RestAdapterBase):
             project: Project to be used.
             log_level: Log level to use.
             session_id: ID of the first job in a runtime session.
+            job_tags: Tags to be assigned to the job.
+            max_execution_time: Maximum execution time in seconds.
+            start_session: Set to True to explicitly start a runtime session. Defaults to False.
 
         Returns:
             JSON response.
         """
         url = self.get_url("jobs")
-        payload = {
+        payload: Dict[str, Any] = {
             "program_id": program_id,
             "params": params,
         }
@@ -150,12 +170,18 @@ class Runtime(RestAdapterBase):
             payload["backend"] = backend_name
         if session_id:
             payload["session_id"] = session_id
+        if job_tags:
+            payload["tags"] = job_tags
+        if max_execution_time:
+            payload["cost"] = max_execution_time
+        if start_session:
+            payload["start_session"] = start_session
         if all([hub, group, project]):
             payload["hub"] = hub
             payload["group"] = group
             payload["project"] = project
         data = json.dumps(payload, cls=RuntimeEncoder)
-        return self.session.post(url, data=data).json()
+        return self.session.post(url, data=data, timeout=900).json()
 
     def jobs_get(
         self,
@@ -166,6 +192,11 @@ class Runtime(RestAdapterBase):
         hub: str = None,
         group: str = None,
         project: str = None,
+        job_tags: Optional[List[str]] = None,
+        session_id: Optional[str] = None,
+        created_after: Optional[datetime] = None,
+        created_before: Optional[datetime] = None,
+        descending: bool = True,
     ) -> Dict:
         """Get a list of job data.
 
@@ -178,12 +209,22 @@ class Runtime(RestAdapterBase):
             hub: Filter by hub - hub, group, and project must all be specified.
             group: Filter by group - hub, group, and project must all be specified.
             project: Filter by project - hub, group, and project must all be specified.
+            job_tags: Filter by tags assigned to jobs. Matched jobs are associated with all tags.
+            session_id: Job ID of the first job in a runtime session.
+            created_after: Filter by the given start date, in local time. This is used to
+                find jobs whose creation dates are after (greater than or equal to) this
+                local date/time.
+            created_before: Filter by the given end date, in local time. This is used to
+                find jobs whose creation dates are before (less than or equal to) this
+                local date/time.
+            descending: If ``True``, return the jobs in descending order of the job
+                creation date (i.e. newest first) until the limit is reached.
 
         Returns:
             JSON response.
         """
         url = self.get_url("jobs")
-        payload: Dict[str, Union[int, str]] = {}
+        payload: Dict[str, Union[int, str, List[str]]] = {}
         if limit:
             payload["limit"] = limit
         if skip:
@@ -192,6 +233,16 @@ class Runtime(RestAdapterBase):
             payload["pending"] = "true" if pending else "false"
         if program_id:
             payload["program"] = program_id
+        if job_tags:
+            payload["tags"] = job_tags
+        if session_id:
+            payload["session_id"] = session_id
+        if created_after:
+            payload["created_after"] = local_to_utc(created_after).isoformat()
+        if created_before:
+            payload["created_before"] = local_to_utc(created_before).isoformat()
+        if descending is False:
+            payload["sort"] = "ASC"
         if all([hub, group, project]):
             payload["provider"] = f"{hub}/{group}/{project}"
         return self.session.get(url, params=payload).json()
