@@ -14,16 +14,20 @@
 
 from qiskit.providers.jobstatus import JobStatus
 
-QISKIT_IBM_RUNTIME_API_URL = "https://auth.quantum-computing.ibm.com/api"
+from .program.result_decoder import ResultDecoder
+from .utils.estimator_result_decoder import EstimatorResultDecoder
+from .utils.sampler_result_decoder import SamplerResultDecoder
+from .utils.runner_result import RunnerResult
 
 
+QISKIT_IBM_RUNTIME_API_URL = "https://auth.quantum-computing.ibm.com/api"
+
 API_TO_JOB_STATUS = {
     "QUEUED": JobStatus.QUEUED,
     "RUNNING": JobStatus.RUNNING,
     "COMPLETED": JobStatus.DONE,
     "FAILED": JobStatus.ERROR,
     "CANCELLED": JobStatus.CANCELLED,
-    "CANCELLED - RAN TOO LONG": JobStatus.ERROR,
 }
 
 API_TO_JOB_ERROR_MESSAGE = {
@@ -31,3 +35,10 @@ API_TO_JOB_ERROR_MESSAGE = {
     "CANCELLED - RAN TOO LONG": "Job {} ran longer than maximum execution time. "
     "Job was cancelled:\n{}",
 }
+
+DEFAULT_DECODERS = {
+    "sampler": [ResultDecoder, SamplerResultDecoder],
+    "estimator": [ResultDecoder, EstimatorResultDecoder],
+    "circuit-runner": RunnerResult,
+    "qasm3-runner": RunnerResult,
+}
