@@ -475,6 +475,10 @@ class IBMBackend(Backend):
     def __repr__(self) -> str:
         return "<{}('{}')>".format(self.__class__.__name__, self.name)
 
+    def __call__(self) -> "IBMBackend":
+        # For backward compatibility only, can be removed later.
+        return self
+
     def run(self, *args: Any, **kwargs: Any) -> None:
         """Not supported method"""
         # pylint: disable=arguments-differ
