@@ -18,7 +18,7 @@ import traceback
 import warnings
 from datetime import datetime
 from collections import OrderedDict
-from typing import Dict, Callable, Optional, Union, List, Any, Type
+from typing import Dict, Callable, Optional, Union, List, Any, Type, Sequence
 
 from qiskit.providers.backend import BackendV1 as Backend
 from qiskit.providers.provider import ProviderV1 as Provider
@@ -109,6 +109,7 @@ class QiskitRuntimeService(Provider):
                 circuits=[psi], observables=[H1], parameter_values=[theta]
             )
             print(f"Estimator results: {job.result()}")
+            session.close()
 
     The example above uses the dedicated :class:`~qiskit_ibm_runtime.Sampler`
     and :class:`~qiskit_ibm_runtime.Estimator` classes. You can also
@@ -448,7 +449,7 @@ class QiskitRuntimeService(Provider):
     def _get_hgp(
         self,
         instance: Optional[str] = None,
-        backend_name: Optional[str] = None,
+        backend_name: Optional[Any] = None,
     ) -> HubGroupProject:
         """Return an instance of `HubGroupProject`.
 
@@ -488,10 +489,17 @@ class QiskitRuntimeService(Provider):
             if hgp.backend(backend_name):
                 return hgp
 
-        raise QiskitBackendNotFoundError(
+        error_message = (
             f"Backend {backend_name} cannot be found in any "
             f"hub/group/project for this account."
         )
+        if not isinstance(backend_name, str):
+            error_message += (
+                f" {backend_name} is of type {type(backend_name)} but should "
+                f"instead be initialized through the {self}."
+            )
+
+        raise QiskitBackendNotFoundError(error_message)
 
     def _discover_backends(self) -> None:
         """Discovers the remote backends for this account, if not already known."""
@@ -851,7 +859,9 @@ class QiskitRuntimeService(Provider):
         inputs: Union[Dict, ParameterNamespace],
         options: Optional[Union[RuntimeOptions, Dict]] = None,
         callback: Optional[Callable] = None,
-        result_decoder: Optional[Type[ResultDecoder]] = None,
+        result_decoder: Optional[
+            Union[Type[ResultDecoder], Sequence[Type[ResultDecoder]]]
+        ] = None,
         instance: Optional[str] = None,
         session_id: Optional[str] = None,
         job_tags: Optional[List[str]] = None,
@@ -874,7 +884,9 @@ class QiskitRuntimeService(Provider):
                     2. Job result.
 
             result_decoder: A :class:`ResultDecoder` subclass used to decode job results.
-                ``ResultDecoder`` is used if not specified.
+                If more than one decoder is specified, the first is used for interim results and
+                the second final results. If not specified, a program-specific decoder or the default
+                ``ResultDecoder`` is used.
             instance: (DEPRECATED) This is only supported for ``ibm_quantum`` runtime and is in the
                 hub/group/project format.
             session_id: Job ID of the first job in a runtime session.
@@ -937,7 +949,6 @@ class QiskitRuntimeService(Provider):
             backend = hgp.backend(qrt_options.backend)
             hgp_name = hgp.name
 
-        result_decoder = result_decoder or ResultDecoder
         try:
             response = self._api_client.program_run(
                 program_id=program_id,
@@ -1427,6 +1438,8 @@ class QiskitRuntimeService(Provider):
             program_id=raw_data.get("program", {}).get("id", ""),
             params=decoded,
             creation_date=raw_data.get("created", None),
+            session_id=raw_data.get("session_id"),
+            tags=raw_data.get("tags"),
         )
 
     def least_busy(
