@@ -12,7 +12,7 @@
 
 """Qiskit runtime job."""
 
-from typing import Any, Optional, Callable, Dict, Type
+from typing import Any, Optional, Callable, Dict, Type, Union, Sequence, List
 import time
 import json
 import logging
@@ -24,11 +24,8 @@ from datetime import datetime
 from qiskit.providers.backend import Backend
 from qiskit.providers.jobstatus import JobStatus, JOB_FINAL_STATES
 from qiskit.providers.job import JobV1 as Job
-from .utils.estimator_result_decoder import EstimatorResultDecoder
-from .utils.sampler_result_decoder import SamplerResultDecoder
 
-
-from .constants import API_TO_JOB_ERROR_MESSAGE, API_TO_JOB_STATUS
+from .constants import API_TO_JOB_ERROR_MESSAGE, API_TO_JOB_STATUS, DEFAULT_DECODERS
 from .exceptions import (
     RuntimeJobFailureError,
     RuntimeInvalidStateError,
@@ -95,8 +92,12 @@ class RuntimeJob(Job):
         params: Optional[Dict] = None,
         creation_date: Optional[str] = None,
         user_callback: Optional[Callable] = None,
-        result_decoder: Type[ResultDecoder] = ResultDecoder,
+        result_decoder: Optional[
+            Union[Type[ResultDecoder], Sequence[Type[ResultDecoder]]]
+        ] = None,
         image: Optional[str] = "",
+        session_id: Optional[str] = None,
+        tags: Optional[List] = None,
     ) -> None:
         """RuntimeJob constructor.
 
@@ -111,6 +112,8 @@ class RuntimeJob(Job):
             user_callback: User callback function.
             result_decoder: A :class:`ResultDecoder` subclass used to decode job results.
             image: Runtime image used for this job: image_name:tag.
+            session_id: Job ID of the first job in a runtime session.
+            tags: Tags assigned to the job.
         """
         super().__init__(backend=backend, job_id=job_id)
         self._api_client = api_client
@@ -122,9 +125,18 @@ class RuntimeJob(Job):
         self._status = JobStatus.INITIALIZING
         self._reason: Optional[str] = None
         self._error_message: Optional[str] = None
-        self._result_decoder = result_decoder
         self._image = image
         self._final_interim_results = False
+        self._session_id = session_id
+        self._tags = tags
+
+        decoder = (
+            result_decoder or DEFAULT_DECODERS.get(program_id, None) or ResultDecoder
+        )
+        if isinstance(decoder, Sequence):
+            self._interim_result_decoder, self._final_result_decoder = decoder
+        else:
+            self._interim_result_decoder = self._final_result_decoder = decoder
 
         # Used for streaming
         self._ws_client_future = None  # type: Optional[futures.Future]
@@ -159,7 +171,7 @@ class RuntimeJob(Job):
             RuntimeJobFailureError: If the job failed.
         """
         if not self._final_interim_results:
-            _decoder = decoder or self._result_decoder
+            _decoder = decoder or self._interim_result_decoder
             interim_results_raw = self._api_client.job_interim_results(
                 job_id=self.job_id()
             )
@@ -186,12 +198,8 @@ class RuntimeJob(Job):
             RuntimeJobFailureError: If the job failed.
             RuntimeJobMaxTimeoutError: If the job does not complete within given timeout.
         """
-        if self.program_id == "sampler":
-            self._result_decoder = SamplerResultDecoder
-        elif self.program_id == "estimator":
-            self._result_decoder = EstimatorResultDecoder
-        _decoder = decoder or self._result_decoder
-        if self._results is None or (_decoder != self._result_decoder):
+        _decoder = decoder or self._final_result_decoder
+        if self._results is None or (_decoder != self._final_result_decoder):
             self.wait_for_final_state(timeout=timeout)
             if self._status == JobStatus.ERROR:
                 error_message = self.error_message()
@@ -244,9 +252,10 @@ class RuntimeJob(Job):
         self,
         timeout: Optional[float] = None,
     ) -> None:
-        """Use the websocket server to wait for the final the state of a job. The server
-            will remain open if the job is still running and the connection will be terminated
-            once the job completes. Then update and return the status of the job.
+        """Use the websocket server to wait for the final the state of a job.
+
+        The server will remain open if the job is still running and the connection will
+        be terminated once the job completes. Then update and return the status of the job.
 
         Args:
             timeout: Seconds to wait for the job. If ``None``, wait indefinitely.
@@ -474,7 +483,7 @@ class RuntimeJob(Job):
             decoder: A :class:`ResultDecoder` (sub)class used to decode job results.
         """
         logger.debug("Start result streaming for job %s", self.job_id())
-        _decoder = decoder or self._result_decoder
+        _decoder = decoder or self._interim_result_decoder
         while True:
             try:
                 response = result_queue.get()
@@ -521,6 +530,9 @@ class RuntimeJob(Job):
         Returns:
             Input parameters used in this job.
         """
+        if not self._params:
+            response = self._api_client.job_get(job_id=self.job_id())
+            self._params = response.get("params", {})
         return self._params
 
     @property
@@ -548,3 +560,21 @@ class RuntimeJob(Job):
             return None
         creation_date_local_dt = utc_to_local(self._creation_date)
         return creation_date_local_dt
+
+    @property
+    def session_id(self) -> str:
+        """Session ID.
+
+        Returns:
+            Job ID of the first job in a runtime session.
+        """
+        return self._session_id
+
+    @property
+    def tags(self) -> List:
+        """Job tags.
+
+        Returns:
+            Tags assigned to the job that can be used for filtering.
+        """
+        return self._tags
