@@ -18,6 +18,7 @@ from qiskit.transpiler.target import Target, InstructionProperties
 from qiskit.utils.units import apply_prefix
 from qiskit.circuit.library.standard_gates import IGate, SXGate, XGate, CXGate, RZGate
 from qiskit.circuit.parameter import Parameter
+from qiskit.circuit.delay import Delay
 from qiskit.circuit.gate import Gate
 from qiskit.circuit.measure import Measure
 from qiskit.circuit.reset import Reset
@@ -131,6 +132,10 @@ def convert_to_target(
                             target[inst][(qubit,)].calibration = sched
                     else:
                         target[inst][qarg].calibration = sched
+    if "delay" not in target:
+        target.add_instruction(
+            Delay(Parameter("t")), {(bit,): None for bit in range(target.num_qubits)}
+        )
     return target
 
 
@@ -142,13 +147,20 @@ def qubit_props_list_from_props(
     """
     qubit_props: List[IBMQubitProperties] = []
     for qubit, _ in enumerate(properties.qubits):
-        t_1 = properties.t1(qubit) * 1e-6  # microseconds to seconds
-        t_2 = properties.t2(qubit) * 1e-6  # microseconds to seconds
-        frequency = properties.frequency(qubit) * 1e9  # GHz to Hz
         try:
-            anharmonicity = (
-                properties.qubit_property(qubit, "anharmonicity")[0] * 1e9
-            )  # GHz to Hz
+            t_1 = properties.t1(qubit)
+        except Exception:  # pylint: disable=broad-except
+            t_1 = None
+        try:
+            t_2 = properties.t2(qubit)
+        except Exception:  # pylint: disable=broad-except
+            t_2 = None
+        try:
+            frequency = properties.frequency(qubit)
+        except Exception:  # pylint: disable=broad-except
+            t_2 = None
+        try:
+            anharmonicity = properties.qubit_property(qubit, "anharmonicity")[0]
         except Exception:  # pylint: disable=broad-except
             anharmonicity = None
         qubit_props.append(
