@@ -37,6 +37,13 @@ try:
 except ImportError:
     HAS_SCIPY = False
 
+try:
+    import qiskit_aer
+
+    HAS_AER = True
+except ImportError:
+    HAS_AER = False
+
 from qiskit.circuit import (
     Instruction,
     Parameter,
@@ -46,6 +53,7 @@ from qiskit.circuit import (
     QuantumRegister,
 )
 from qiskit.circuit.library import BlueprintCircuit
+from qiskit.circuit.parametertable import ParameterView
 from qiskit.result import Result
 from qiskit.version import __version__ as _terra_version_string
 
@@ -233,6 +241,8 @@ class RuntimeEncoder(json.JSONEncoder):
                 compress=False,
             )
             return {"__type__": "ParameterExpression", "__value__": value}
+        if isinstance(obj, ParameterView):
+            return obj.data
         if isinstance(obj, Instruction):
             # Append instruction to empty circuit
             quantum_register = QuantumRegister(obj.num_qubits)
@@ -243,6 +253,8 @@ class RuntimeEncoder(json.JSONEncoder):
                 serializer=lambda buff, data: dump(data, buff),  # type: ignore[no-untyped-call]
             )
             return {"__type__": "Instruction", "__value__": value}
+        if HAS_AER and isinstance(obj, qiskit_aer.noise.NoiseModel):
+            return {"__type__": "NoiseModel", "__value__": obj.to_dict()}
         if hasattr(obj, "settings"):
             return {
                 "__type__": "settings",
@@ -317,4 +329,9 @@ class RuntimeDecoder(json.JSONDecoder):
                 return _decode_and_deserialize(obj_val, scipy.sparse.load_npz, False)
             if obj_type == "to_json":
                 return obj_val
+            if obj_type == "NoiseModel":
+                if HAS_AER:
+                    return qiskit_aer.noise.NoiseModel.from_dict(obj_val)
+                warnings.warn("Qiskit Aer is needed to restore noise model.")
+                return obj_val
         return obj
