@@ -111,6 +111,7 @@ class TestIntegrationEstimator(IBMIntegrationTestCase):
             self.assertIsInstance(result5, EstimatorResult)
             self.assertEqual(len(result5.values), len(circuits5))
             self.assertEqual(len(result5.metadata), len(circuits5))
+            session.close()
 
     @unittest.skip("Skip until data caching is reenabled.")
     @run_integration_test
@@ -164,6 +165,7 @@ class TestIntegrationEstimator(IBMIntegrationTestCase):
             self.assertEqual(result.values[0], -1)
             self.assertNotEqual(result.values[1], -1)
             self.assertNotEqual(result.values[1], 1)
+            session.close()
 
     @unittest.skip("Skip until data caching is reenabled.")
     @run_integration_test
@@ -199,6 +201,7 @@ class TestIntegrationEstimator(IBMIntegrationTestCase):
             )
             with self.assertRaises(RuntimeJobFailureError):
                 job.result()
+            session.close()
 
     @run_integration_test
     def test_estimator_primitive(self, service):
@@ -282,12 +285,15 @@ class TestIntegrationEstimator(IBMIntegrationTestCase):
         with Session(service, self.backend) as session:
             estimator = Estimator(session=session)
             job = estimator.run(
-                circuits=[bell] * 40, observables=[obs] * 40, callback=_callback
+                circuits=[bell] * 60, observables=[obs] * 60, callback=_callback
             )
             result = job.result()
-            self.assertTrue((result.values == ws_result[-1].values).all())
+            self.assertIsInstance(ws_result[-1], dict)
+            ws_result_values = np.asarray(ws_result[-1]["values"])
+            self.assertTrue((result.values == ws_result_values).all())
             self.assertEqual(len(job_ids), 1)
             self.assertEqual(job.job_id(), job_ids.pop())
+            session.close()
 
     @run_integration_test
     def test_estimator_coeffs(self, service):
@@ -337,6 +343,7 @@ class TestIntegrationEstimator(IBMIntegrationTestCase):
 
             chsh1_runtime = job1.result()
             chsh2_runtime = job2.result()
+            session.close()
 
         self.assertTrue(np.allclose(chsh1_terra.values, chsh1_runtime.values, rtol=0.3))
         self.assertTrue(np.allclose(chsh2_terra.values, chsh2_runtime.values, rtol=0.3))
