@@ -24,6 +24,7 @@ from qiskit_ibm_runtime.exceptions import (
     RuntimeJobFailureError,
     RuntimeInvalidStateError,
     RuntimeJobNotFound,
+    RuntimeJobMaxTimeoutError,
 )
 from ..ibm_test_case import IBMIntegrationJobTestCase
 from ..decorators import run_integration_test
@@ -64,7 +65,7 @@ class TestIntegrationJob(IBMIntegrationJobTestCase):
             self.skipTest("Not supported on ibm_quantum")
 
         job = self._run_program(service, backend="")
-        self.assertTrue(job.backend, f"Job {job.job_id} has no backend.")
+        self.assertTrue(job.backend(), f"Job {job.job_id()} has no backend.")
 
     @run_integration_test
     def test_run_program_log_level(self, service):
@@ -86,36 +87,37 @@ class TestIntegrationJob(IBMIntegrationJobTestCase):
         """Test a failed program execution."""
         job = self._run_program(service, inputs={})
         job.wait_for_final_state()
-        job_result_raw = service._api_client.job_results(job.job_id)
+        job_result_raw = service._api_client.job_results(job.job_id())
         self.assertEqual(JobStatus.ERROR, job.status())
         self.assertIn(
-            API_TO_JOB_ERROR_MESSAGE["FAILED"].format(job.job_id, job_result_raw),
+            API_TO_JOB_ERROR_MESSAGE["FAILED"].format(job.job_id(), job_result_raw),
             job.error_message(),
         )
-        with self.assertRaises(RuntimeJobFailureError) as err_cm:
+        with self.assertRaises(RuntimeJobFailureError):
             job.result()
-        self.assertIn("KeyError", str(err_cm.exception))
+        # TODO: Re-enable when ntc-1651 is fixed
+        # self.assertIn("KeyError", str(err_cm.exception))
 
     @run_integration_test
     def test_run_program_failed_ran_too_long(self, service):
         """Test a program that failed since it ran longer than maximum execution time."""
         max_execution_time = 60
-        inputs = {"iterations": 1, "sleep_per_iteration": 60}
+        inputs = {"iterations": 1, "sleep_per_iteration": 61}
         program_id = self._upload_program(
             service, max_execution_time=max_execution_time
         )
         job = self._run_program(service, program_id=program_id, inputs=inputs)
 
         job.wait_for_final_state()
-        job_result_raw = service._api_client.job_results(job.job_id)
+        job_result_raw = service._api_client.job_results(job.job_id())
         self.assertEqual(JobStatus.ERROR, job.status())
         self.assertIn(
             API_TO_JOB_ERROR_MESSAGE["CANCELLED - RAN TOO LONG"].format(
-                job.job_id, job_result_raw
+                job.job_id(), job_result_raw
             ),
             job.error_message(),
         )
-        with self.assertRaises(RuntimeJobFailureError):
+        with self.assertRaises(RuntimeJobMaxTimeoutError):
             job.result()
 
     @run_integration_test
@@ -131,7 +133,7 @@ class TestIntegrationJob(IBMIntegrationJobTestCase):
         )
         job.wait_for_final_state()
         self.assertEqual(
-            job._api_client.job_get(job.job_id)["cost"], job_max_execution_time
+            job._api_client.job_get(job.job_id())["cost"], job_max_execution_time
         )
 
     @run_integration_test
@@ -140,13 +142,6 @@ class TestIntegrationJob(IBMIntegrationJobTestCase):
         with self.assertRaises(IBMRuntimeError):
             self._run_program(service, max_execution_time=299)
 
-    @run_integration_test
-    def test_run_program_failed_invalid_execution_time(self, service):
-        """Test a program that failed with an invalid execution time."""
-        program_id = self._upload_program(service)
-        with self.assertRaises(IBMRuntimeError):
-            self._run_program(service, program_id=program_id, max_execution_time=5000)
-
     @run_integration_test
     def test_cancel_job_queued(self, service):
         """Test canceling a queued job."""
@@ -157,7 +152,7 @@ class TestIntegrationJob(IBMIntegrationJobTestCase):
         if not cancel_job_safe(job, self.log):
             return
         time.sleep(10)  # Wait a bit for DB to update.
-        rjob = service.job(job.job_id)
+        rjob = service.job(job.job_id())
         self.assertEqual(rjob.status(), JobStatus.CANCELLED)
 
     @run_integration_test
@@ -168,7 +163,7 @@ class TestIntegrationJob(IBMIntegrationJobTestCase):
         if not cancel_job_safe(job, self.log):
             return
         time.sleep(10)  # Wait a bit for DB to update.
-        rjob = service.job(job.job_id)
+        rjob = service.job(job.job_id())
         self.assertEqual(rjob.status(), JobStatus.CANCELLED)
 
     @run_integration_test
@@ -187,9 +182,9 @@ class TestIntegrationJob(IBMIntegrationJobTestCase):
             with self.subTest(status=status):
                 job = self._run_program(service, iterations=2)
                 wait_for_status(job, status)
-                service.delete_job(job.job_id)
+                service.delete_job(job.job_id())
                 with self.assertRaises(RuntimeJobNotFound):
-                    service.job(job.job_id)
+                    service.job(job.job_id())
 
     @run_integration_test
     def test_delete_job_queued(self, service):
@@ -198,9 +193,9 @@ class TestIntegrationJob(IBMIntegrationJobTestCase):
         _ = self._run_program(service, iterations=10, backend=real_device)
         job = self._run_program(service, iterations=2, backend=real_device)
         wait_for_status(job, JobStatus.QUEUED)
-        service.delete_job(job.job_id)
+        service.delete_job(job.job_id())
         with self.assertRaises(RuntimeJobNotFound):
-            service.job(job.job_id)
+            service.job(job.job_id())
 
     @run_integration_test
     def test_final_result(self, service):
@@ -210,7 +205,7 @@ class TestIntegrationJob(IBMIntegrationJobTestCase):
         result = job.result(decoder=SerializableClassDecoder)
         self.assertEqual(final_result, result)
 
-        rresults = service.job(job.job_id).result(decoder=SerializableClassDecoder)
+        rresults = service.job(job.job_id()).result(decoder=SerializableClassDecoder)
         self.assertEqual(final_result, rresults)
 
     @run_integration_test
@@ -227,7 +222,7 @@ class TestIntegrationJob(IBMIntegrationJobTestCase):
         inputs = {"iterations": 1, "interim_results": interim_results}
         job = self._run_program(service, inputs=inputs)
         self.assertEqual(inputs, job.inputs)
-        rjob = service.job(job.job_id)
+        rjob = service.job(job.job_id())
         rinterim_results = rjob.inputs["interim_results"]
         self._assert_complex_types_equal(interim_results, rinterim_results)
 
@@ -235,7 +230,7 @@ class TestIntegrationJob(IBMIntegrationJobTestCase):
     def test_job_backend(self, service):
         """Test job backend."""
         job = self._run_program(service)
-        self.assertEqual(self.sim_backends[service.channel], job.backend.name)
+        self.assertEqual(self.sim_backends[service.channel], job.backend().name)
 
     @run_integration_test
     def test_job_program_id(self, service):
@@ -265,7 +260,7 @@ class TestIntegrationJob(IBMIntegrationJobTestCase):
         """Test job creation date."""
         job = self._run_program(service, iterations=1)
         self.assertTrue(job.creation_date)
-        rjob = service.job(job.job_id)
+        rjob = service.job(job.job_id())
         self.assertTrue(rjob.creation_date)
         rjobs = service.jobs(limit=2)
         for rjob in rjobs:
@@ -282,6 +277,16 @@ class TestIntegrationJob(IBMIntegrationJobTestCase):
         self.assertIn("this is a stdout message", job_logs)
         self.assertIn("this is a stderr message", job_logs)
 
+    @run_integration_test
+    def test_job_metrics(self, service):
+        """Test job metrics."""
+        job = self._run_program(service)
+        job.wait_for_final_state()
+        metrics = job.metrics()
+        self.assertTrue(metrics)
+        self.assertIn("timestamps", metrics)
+        self.assertIn("qiskit_version", metrics)
+
     def _assert_complex_types_equal(self, expected, received):
         """Verify the received data in complex types is expected."""
         if "serializable_class" in received:
